"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }// packages/native-federation-typescript/src/index.ts
var _unplugin = require('unplugin');
var _fs = require('fs'); var _fs2 = _interopRequireDefault(_fs);






var _dtskit = require('@module-federation/dts-kit');
var NativeFederationTypeScriptRemote = _unplugin.createUnplugin.call(void 0, 
  (enhancedOptions) => {
    const options = "extraOptions" in enhancedOptions ? enhancedOptions.remote : enhancedOptions;
    const extraOptions = "extraOptions" in enhancedOptions ? enhancedOptions.extraOptions : void 0;
    _dtskit.validateOptions.call(void 0, options);
    const isProd = process.env.NODE_ENV === "production";
    const generateTypesOptions = {
      remote: options,
      extraOptions
    };
    const getGenerateTypesFn = () => {
      let fn = _dtskit.generateTypes;
      let res;
      if (options.compileInChildProcess) {
        fn = _dtskit.generateTypesInChildProcess;
      }
      if (isProd) {
        res = fn(generateTypesOptions);
        return () => res;
      }
      return fn;
    };
    const generateTypesFn = getGenerateTypesFn();
    return {
      name: "native-federation-typescript/remote",
      rollup: {
        writeBundle: async () => {
          await generateTypesFn(generateTypesOptions);
        }
      },
      vite: {
        buildStart: async () => {
          if (isProd) {
            return;
          }
          await generateTypesFn(generateTypesOptions);
        },
        watchChange: async () => {
          if (isProd) {
            return;
          }
          await generateTypesFn(generateTypesOptions);
        },
        writeBundle: async () => {
          await generateTypesFn(generateTypesOptions);
        }
      },
      webpack: (compiler) => {
        compiler.hooks.thisCompilation.tap("generateTypes", (compilation) => {
          compilation.hooks.processAssets.tapPromise(
            {
              name: "generateTypes",
              stage: (
                // @ts-expect-error use runtime variable in case peer dep not installed
                compilation.constructor.PROCESS_ASSETS_STAGE_OPTIMIZE_TRANSFER
              )
            },
            async () => {
              try {
                await generateTypesFn(generateTypesOptions);
                const { zipTypesPath, apiTypesPath, zipName, apiFileName } = _dtskit.retrieveTypesAssetsInfo.call(void 0, options);
                if (zipTypesPath) {
                  compilation.emitAsset(
                    zipName,
                    new compiler.webpack.sources.RawSource(
                      _fs2.default.readFileSync(zipTypesPath),
                      false
                    )
                  );
                }
                if (apiTypesPath) {
                  compilation.emitAsset(
                    apiFileName,
                    new compiler.webpack.sources.RawSource(
                      _fs2.default.readFileSync(apiTypesPath),
                      false
                    )
                  );
                }
              } catch (err) {
                console.error(err);
              }
            }
          );
        });
      },
      rspack: (compiler) => {
        compiler.hooks.thisCompilation.tap("generateTypes", (compilation) => {
          compilation.hooks.processAssets.tapPromise(
            {
              name: "generateTypes",
              stage: (
                // @ts-expect-error use runtime variable in case peer dep not installed
                compilation.constructor.PROCESS_ASSETS_STAGE_OPTIMIZE_TRANSFER
              )
            },
            async () => {
              try {
                await generateTypesFn(generateTypesOptions);
                const { zipTypesPath, apiTypesPath, zipName, apiFileName } = _dtskit.retrieveTypesAssetsInfo.call(void 0, options);
                if (zipTypesPath) {
                  compilation.emitAsset(
                    zipName,
                    new compiler.webpack.sources.RawSource(
                      _fs2.default.readFileSync(zipTypesPath),
                      false
                    )
                  );
                }
                if (apiTypesPath) {
                  compilation.emitAsset(
                    apiFileName,
                    new compiler.webpack.sources.RawSource(
                      _fs2.default.readFileSync(apiTypesPath),
                      false
                    )
                  );
                }
              } catch (err) {
                console.error(err);
              }
            }
          );
        });
      }
    };
  }
);
var NativeFederationTypeScriptHost = _unplugin.createUnplugin.call(void 0, 
  (enhancedOptions) => {
    const options = "extraOptions" in enhancedOptions ? enhancedOptions.host : enhancedOptions;
    const extraOptions = "extraOptions" in enhancedOptions ? enhancedOptions.extraOptions : void 0;
    _dtskit.validateOptions.call(void 0, options);
    const consumeTypesOptions = {
      host: options,
      extraOptions
    };
    const consumeTypesPromise = _dtskit.consumeTypes.call(void 0, consumeTypesOptions);
    return {
      name: "native-federation-typescript/host",
      async writeBundle() {
        await consumeTypesPromise;
      },
      get vite() {
        return process.env.NODE_ENV === "production" ? void 0 : {
          buildStart: async () => {
            await consumeTypesPromise;
          }
        };
      }
    };
  }
);




exports.NativeFederationTypeScriptRemote = NativeFederationTypeScriptRemote; exports.NativeFederationTypeScriptHost = NativeFederationTypeScriptHost;
